import os

from twisted.python import util

from twisted.application import internet, service

from nevow import appserver
from nevow import loaders
from nevow import rend
from nevow import tags as T
from nevow import stan
from nevow import inevow
from nevow import url
from nevow.i18n import _, I18NConfig

import formless
from formless import annotate, webform

LOCALE_DIR = util.sibpath('/home/richard/workspace/www.medicalresearch.org.uk/test/i18n/test.tac', 'locale')


langs = [d for d in os.listdir(LOCALE_DIR) if d != '.svn']
langs.sort()

class Common(rend.Page):
    
    addSlash = True
    
    def renderHTTP(self, ctx):
        
        # We're only overriding renderHTTP to look for a 'lang' query parameter
        # without cluttering up the messages renderer, below.
        
        # If 'lang' is present then we "force" the translation language. This
        # simulates how user preferences from the session might be used to
        # override the browser's language settings.
        lang = ctx.arg('lang')
        if lang is not None:
            ctx.remember([lang], inevow.ILanguages)
            
        # Let the base class handle it, really.
        return rend.Page.renderHTTP(self, ctx)

    def render_langs(self, ctx, data):
        """Render a list of links to select from the available translations.
        """
        out = [T.a(href=url.here.remove('lang'))['default'], ' | ']
        for lang in langs:
            out.append(T.a(href=url.here.replace('lang', lang))[lang])
            out.append(' | ')
        return out[:-1]

class Page(Common):
    def render_message(self, ctx, data):
        """Render a localised message. The _(..) construct looks the
        translation up at render time.
        """
        return ctx.tag.clear()[_('Hello')]
    
    def saveRecord(self, title):
        print title
    
    def bind_saveRecord(self, ctx):
        return formless.MethodBinding(
        'saveRecord',
        formless.Method(
            arguments=[
                formless.Argument(
                    'title', 
                    annotate.String(label=_('Title'), required=True, requiredFailMessage=_('Please enter a title'))
                )
            ]
        ),
        action="Save Record")
    
    docFactory = loaders.stan(
        T.html[
            T.body[
                T.p['Select you preferred language: ', T.directive('langs')],
                T.p[render_message],
                T.div[webform.renderForms()]
                ],
            ]
        )

root = Page()
root.remember(I18NConfig(domain='test', localeDir=LOCALE_DIR), inevow.II18NConfig)

application = service.Application('i18n')
webServer = internet.TCPServer(8080, appserver.NevowSite(root))
webServer.setServiceParent(application)